==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkGDALRasterReader.java <==
// java wrapper for vtkGDALRasterReader object
//

package vtk;
import vtk.*;

public class vtkGDALRasterReader extends vtkImageReader2
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native String GetProjectionString_4();
  public String GetProjectionString()
    { return GetProjectionString_4(); }

  private native void SetTargetDimensions_5(int id0,int id1);
  public void SetTargetDimensions(int id0,int id1)
    { SetTargetDimensions_5(id0,id1); }

  private native void SetTargetDimensions_6(int id0[]);
  public void SetTargetDimensions(int id0[])
    { SetTargetDimensions_6(id0); }

  private native int[]  GetTargetDimensions_7();
  public int[]  GetTargetDimensions()
    { return GetTargetDimensions_7(); }

  private native int[]  GetRasterDimensions_8();
  public int[]  GetRasterDimensions()
    { return GetRasterDimensions_8(); }

  private native double GetInvalidValue_9();
  public double GetInvalidValue()
    { return GetInvalidValue_9(); }

  private native String GetDriverShortName_10();
  public String GetDriverShortName()
    { return GetDriverShortName_10(); }

  private native String GetDriverLongName_11();
  public String GetDriverLongName()
    { return GetDriverLongName_11(); }

  public vtkGDALRasterReader() { super(); }

  public vtkGDALRasterReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-2-armv6h.pkg.tar.xz: vtk/vtkGDALRasterReader.java <==
// java wrapper for vtkGDALRasterReader object
//

package vtk;
import vtk.*;

public class vtkGDALRasterReader extends vtkImageReader2
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native String GetProjectionString_4();
  public String GetProjectionString()
    { return GetProjectionString_4(); }

  private native void SetTargetDimensions_5(int id0,int id1);
  public void SetTargetDimensions(int id0,int id1)
    { SetTargetDimensions_5(id0,id1); }

  private native void SetTargetDimensions_6(int id0[]);
  public void SetTargetDimensions(int id0[])
    { SetTargetDimensions_6(id0); }

  private native int[]  GetTargetDimensions_7();
  public int[]  GetTargetDimensions()
    { return GetTargetDimensions_7(); }

  private native int[]  GetRasterDimensions_8();
  public int[]  GetRasterDimensions()
    { return GetRasterDimensions_8(); }

  private native double GetInvalidValue_9();
  public double GetInvalidValue()
    { return GetInvalidValue_9(); }

  private native String GetDriverShortName_10();
  public String GetDriverShortName()
    { return GetDriverShortName_10(); }

  private native String GetDriverLongName_11();
  public String GetDriverLongName()
    { return GetDriverLongName_11(); }

  private native int GetNumberOfPoints_12();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_12(); }

  public vtkGDALRasterReader() { super(); }

  public vtkGDALRasterReader(long id) { super(id); }
  public native long   VTKInit();

}
